__title__ = 'httpx-socks'
__version__ = '0.2.10'

from python_socks import (
    ProxyError,
    ProxyTimeoutError,
    ProxyConnectionError,
    ProxyType
)

from ._sync_transport import SyncProxyTransport
from ._async_transport import AsyncProxyTransport

__all__ = (
    '__title__',
    '__version__',
    'SyncProxyTransport',
    'AsyncProxyTransport',
    'ProxyError',
    'ProxyTimeoutError',
    'ProxyConnectionError',
    'ProxyType',
)
